6617183 CIFS Service - PSARC 2006/715 (fix merge, unref, versioning)
authoramw
Mon, 29 Oct 2007 16:16:37 -0700
changeset 5366 5a99671e8d50
parent 5365 e9a7403eebeb
child 5367 c40abbe796be
6617183 CIFS Service - PSARC 2006/715 (fix merge, unref, versioning) 6622467 ndrgen does not understand -_gcc which breaks the real gcc build
deleted_files/usr/src/lib/smbsrv/libmlsvc/common/mlsvc_spoolss.c
usr/src/lib/libbsm/audit_event.txt
usr/src/lib/smbsrv/libmlsvc/common/mlsvc_spoolss.c
usr/src/pkgdefs/SUNWsmbsu/prototype_com
usr/src/pkgdefs/SUNWsmbsu/prototype_i386
usr/src/pkgdefs/SUNWsmbsu/prototype_sparc
usr/src/tools/abi/etc/exceptions
usr/src/tools/findunref/exception_list
usr/src/tools/ndrgen/ndrgen.sh
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/deleted_files/usr/src/lib/smbsrv/libmlsvc/common/mlsvc_spoolss.c	Mon Oct 29 16:16:37 2007 -0700
@@ -0,0 +1,139 @@
+/*
+ * CDDL HEADER START
+ *
+ * The contents of this file are subject to the terms of the
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
+ *
+ * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
+ * or http://www.opensolaris.org/os/licensing.
+ * See the License for the specific language governing permissions
+ * and limitations under the License.
+ *
+ * When distributing Covered Code, include this CDDL HEADER in each
+ * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
+ * If applicable, add the following below this CDDL HEADER, with the
+ * fields enclosed by brackets "[]" replaced with your own identifying
+ * information: Portions Copyright [yyyy] [name of copyright owner]
+ *
+ * CDDL HEADER END
+ */
+/*
+ * Copyright 2007 Sun Microsystems, Inc.  All rights reserved.
+ * Use is subject to license terms.
+ */
+
+#pragma ident	"%Z%%M%	%I%	%E% SMI"
+
+/*
+ * Printing and Spooling RPC interface definition.
+ * A stub to resolve RPC requests to this service.
+ */
+
+#include <smbsrv/ndl/spoolss.ndl>
+#include <smbsrv/mlsvc_util.h>
+#include <smbsrv/ntstatus.h>
+#include <smbsrv/nmpipes.h>
+
+static mlrpc_stub_table_t spoolss_stub_table[];
+
+static mlrpc_service_t spoolss_service = {
+	"SPOOLSS",			/* name */
+	"Print Spool Service",		/* desc */
+	"\\spoolss",			/* endpoint */
+	PIPE_SPOOLSS,			/* sec_addr_port */
+	"12345678-1234-abcd-ef000123456789ab", 1,	/* abstract */
+	"8a885d04-1ceb-11c9-9fe808002b104860", 2,	/* transfer */
+	0,				/* no bind_instance_size */
+	0,				/* no bind_req() */
+	0,				/* no unbind_and_close() */
+	0,				/* use generic_call_stub() */
+	&TYPEINFO(spoolss_interface),	/* interface ti */
+	spoolss_stub_table		/* stub_table */
+};
+
+/*
+ * spoolss_initialize
+ *
+ * This function registers the SPOOLSS RPC interface with the RPC
+ * runtime library. It must be called in order to use either the
+ * client side or the server side functions.
+ */
+void
+spoolss_initialize(void)
+{
+	(void) mlrpc_register_service(&spoolss_service);
+}
+
+/*
+ * spoolss_s_OpenPrinter
+ *
+ * We don't offer print spooling support. It should be okay to
+ * set the status to access denied and return MLRPC_DRC_OK.
+ */
+static int
+spoolss_s_OpenPrinter(void *arg, struct mlrpc_xaction *mxa)
+{
+	struct spoolss_OpenPrinter *param = arg;
+
+	bzero(param, sizeof (struct spoolss_OpenPrinter));
+	param->status = NT_SC_ERROR(NT_STATUS_ACCESS_DENIED);
+
+	return (MLRPC_DRC_OK);
+}
+
+
+/*
+ * spoolss_s_stub
+ */
+static int
+spoolss_s_stub(void *arg, struct mlrpc_xaction *mxa)
+{
+	return (MLRPC_DRC_FAULT_PARAM_0_UNIMPLEMENTED);
+}
+
+static mlrpc_stub_table_t spoolss_stub_table[] = {
+	{ spoolss_s_OpenPrinter, SPOOLSS_OPNUM_OpenPrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetJob },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetPrinterDriver },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinterDriver },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPrintProcessor },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetPrintProcessorDirectory },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AbortPrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ReadPrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_WaitForPrinterChange },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddForm },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeleteForm },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetForm },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_SetForm },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_EnumMonitors },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPort },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ConfigurePort },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePort },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_CreatePrinterIc },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_PlayDescriptionPrinterIc },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinterIc },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPrinterConnection },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinterConnection },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_PrinterMessageBox },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddMonitor },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeleteMonitor },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrintProcessor },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPrintProvider },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrintProvider },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ResetPrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_FindFirstChangeNotify },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_FindNextChangeNotify },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RouterFindFirstNotify },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ReplyOpenPrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RouterReplyPrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ReplyClosePrinter },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPortEx },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RemoteFindFirstChangeNotify },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_SpoolerInitialize },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ResetPrinterEx },
+	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RouterRefreshChangeNotify },
+	{ spoolss_s_OpenPrinter, SPOOLSS_OPNUM_OpenPrinter2 },
+	{0}
+};
--- a/usr/src/lib/libbsm/audit_event.txt	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/lib/libbsm/audit_event.txt	Mon Oct 29 16:16:37 2007 -0700
@@ -444,8 +444,8 @@
 6241:AUE_uadmin_remount:uadmin(1m) - remount:ss
 6242:AUE_uadmin_ftrace:uadmin(1m) - ftrace:ss
 6243:AUE_uadmin_swapctl:uadmin(1m) - swapctl:ss
-6237:AUE_smbd_session:smbd(1m) session setup:lo
-6238:AUE_smbd_logoff:smbd(1m) session logoff:lo
+6244:AUE_smbd_session:smbd(1m) session setup:lo
+6245:AUE_smbd_logoff:smbd(1m) session logoff:lo
 #
 # Trusted Extensions events:
 #
--- a/usr/src/lib/smbsrv/libmlsvc/common/mlsvc_spoolss.c	Mon Oct 29 15:08:19 2007 -0700
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,139 +0,0 @@
-/*
- * CDDL HEADER START
- *
- * The contents of this file are subject to the terms of the
- * Common Development and Distribution License (the "License").
- * You may not use this file except in compliance with the License.
- *
- * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
- * or http://www.opensolaris.org/os/licensing.
- * See the License for the specific language governing permissions
- * and limitations under the License.
- *
- * When distributing Covered Code, include this CDDL HEADER in each
- * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
- * If applicable, add the following below this CDDL HEADER, with the
- * fields enclosed by brackets "[]" replaced with your own identifying
- * information: Portions Copyright [yyyy] [name of copyright owner]
- *
- * CDDL HEADER END
- */
-/*
- * Copyright 2007 Sun Microsystems, Inc.  All rights reserved.
- * Use is subject to license terms.
- */
-
-#pragma ident	"%Z%%M%	%I%	%E% SMI"
-
-/*
- * Printing and Spooling RPC interface definition.
- * A stub to resolve RPC requests to this service.
- */
-
-#include <smbsrv/ndl/spoolss.ndl>
-#include <smbsrv/mlsvc_util.h>
-#include <smbsrv/ntstatus.h>
-#include <smbsrv/nmpipes.h>
-
-static mlrpc_stub_table_t spoolss_stub_table[];
-
-static mlrpc_service_t spoolss_service = {
-	"SPOOLSS",			/* name */
-	"Print Spool Service",		/* desc */
-	"\\spoolss",			/* endpoint */
-	PIPE_SPOOLSS,			/* sec_addr_port */
-	"12345678-1234-abcd-ef000123456789ab", 1,	/* abstract */
-	"8a885d04-1ceb-11c9-9fe808002b104860", 2,	/* transfer */
-	0,				/* no bind_instance_size */
-	0,				/* no bind_req() */
-	0,				/* no unbind_and_close() */
-	0,				/* use generic_call_stub() */
-	&TYPEINFO(spoolss_interface),	/* interface ti */
-	spoolss_stub_table		/* stub_table */
-};
-
-/*
- * spoolss_initialize
- *
- * This function registers the SPOOLSS RPC interface with the RPC
- * runtime library. It must be called in order to use either the
- * client side or the server side functions.
- */
-void
-spoolss_initialize(void)
-{
-	(void) mlrpc_register_service(&spoolss_service);
-}
-
-/*
- * spoolss_s_OpenPrinter
- *
- * We don't offer print spooling support. It should be okay to
- * set the status to access denied and return MLRPC_DRC_OK.
- */
-static int
-spoolss_s_OpenPrinter(void *arg, struct mlrpc_xaction *mxa)
-{
-	struct spoolss_OpenPrinter *param = arg;
-
-	bzero(param, sizeof (struct spoolss_OpenPrinter));
-	param->status = NT_SC_ERROR(NT_STATUS_ACCESS_DENIED);
-
-	return (MLRPC_DRC_OK);
-}
-
-
-/*
- * spoolss_s_stub
- */
-static int
-spoolss_s_stub(void *arg, struct mlrpc_xaction *mxa)
-{
-	return (MLRPC_DRC_FAULT_PARAM_0_UNIMPLEMENTED);
-}
-
-static mlrpc_stub_table_t spoolss_stub_table[] = {
-	{ spoolss_s_OpenPrinter, SPOOLSS_OPNUM_OpenPrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetJob },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetPrinterDriver },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinterDriver },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPrintProcessor },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetPrintProcessorDirectory },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AbortPrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ReadPrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_WaitForPrinterChange },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddForm },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeleteForm },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_GetForm },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_SetForm },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_EnumMonitors },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPort },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ConfigurePort },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePort },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_CreatePrinterIc },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_PlayDescriptionPrinterIc },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinterIc },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPrinterConnection },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrinterConnection },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_PrinterMessageBox },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddMonitor },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeleteMonitor },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrintProcessor },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPrintProvider },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_DeletePrintProvider },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ResetPrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_FindFirstChangeNotify },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_FindNextChangeNotify },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RouterFindFirstNotify },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ReplyOpenPrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RouterReplyPrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ReplyClosePrinter },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_AddPortEx },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RemoteFindFirstChangeNotify },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_SpoolerInitialize },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_ResetPrinterEx },
-	{ spoolss_s_stub,	 SPOOLSS_OPNUM_RouterRefreshChangeNotify },
-	{ spoolss_s_OpenPrinter, SPOOLSS_OPNUM_OpenPrinter2 },
-	{0}
-};
--- a/usr/src/pkgdefs/SUNWsmbsu/prototype_com	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/pkgdefs/SUNWsmbsu/prototype_com	Mon Oct 29 16:16:37 2007 -0700
@@ -64,7 +64,6 @@
 d none usr/lib/fs 755 root sys
 d none usr/lib/fs/smb 755 root sys
 f none usr/lib/fs/smb/libshare_smb.so.1 755 root bin
-s none usr/lib/fs/smb/libshare_smb.so=libshare_smb.so.1
 d none usr/lib/security 755 root bin
 f none usr/lib/security/pam_smb_passwd.so.1 755 root bin
 s none usr/lib/security/pam_smb_passwd.so=./pam_smb_passwd.so.1
--- a/usr/src/pkgdefs/SUNWsmbsu/prototype_i386	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/pkgdefs/SUNWsmbsu/prototype_i386	Mon Oct 29 16:16:37 2007 -0700
@@ -30,4 +30,3 @@
 f none usr/lib/mdb/kvm/amd64/smbsrv.so 555 root sys
 d none usr/lib/fs/smb/amd64 755 root sys
 f none usr/lib/fs/smb/amd64/libshare_smb.so.1 755 root bin
-s none usr/lib/fs/smb/amd64/libshare_smb.so=libshare_smb.so.1
--- a/usr/src/pkgdefs/SUNWsmbsu/prototype_sparc	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/pkgdefs/SUNWsmbsu/prototype_sparc	Mon Oct 29 16:16:37 2007 -0700
@@ -29,4 +29,3 @@
 f none usr/lib/mdb/kvm/sparcv9/smbsrv.so 555 root sys
 d none usr/lib/fs/smb/sparcv9 755 root sys
 f none usr/lib/fs/smb/sparcv9/libshare_smb.so.1 755 root bin
-s none usr/lib/fs/smb/sparcv9/libshare_smb.so=libshare_smb.so.1
--- a/usr/src/tools/abi/etc/exceptions	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/tools/abi/etc/exceptions	Mon Oct 29 16:16:37 2007 -0700
@@ -438,7 +438,12 @@
 PSARC 2006/277: RULE W3: usr/lib/krb5/db2.so.1
 PSARC 2006/277: RULE W3: usr/lib/krb5/kldap.so.1
 PSARC 2006/277: RULE W3: usr/lib/krb5/libkdb_ldap.so.1
- 
+PSARC 2006/715: RULE W3: usr/lib/smbsrv/libmlrpc.so.1
+PSARC 2006/715: RULE W3: usr/lib/smbsrv/libmlsvc.so.1
+PSARC 2006/715: RULE W3: usr/lib/smbsrv/libsmb.so.1
+PSARC 2006/715: RULE W3: usr/lib/smbsrv/libsmbns.so.1
+PSARC 2006/715: RULE W3: usr/lib/smbsrv/libsmbrdr.so.1
+
 #############################################
 # WARNINGs exempted from RULE W4 (See RULES section of intf_check manpage) 
 # exempts libraries with no versions found
--- a/usr/src/tools/findunref/exception_list	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/tools/findunref/exception_list	Mon Oct 29 16:16:37 2007 -0700
@@ -207,6 +207,18 @@
 #
 ./src/cmd/syslogd/sparcv9/Makefile
 ./src/uts/sparc/uhci/Makefile
+./src/lib/pam_modules/smb/amd64/Makefile
+./src/lib/pam_modules/smb/sparcv9/Makefile
+./src/lib/smbsrv/libmlrpc/amd64/Makefile
+./src/lib/smbsrv/libmlrpc/sparcv9/Makefile
+./src/lib/smbsrv/libmlsvc/amd64/Makefile
+./src/lib/smbsrv/libmlsvc/sparcv9/Makefile
+./src/lib/smbsrv/libsmb/amd64/Makefile
+./src/lib/smbsrv/libsmb/sparcv9/Makefile
+./src/lib/smbsrv/libsmbns/amd64/Makefile
+./src/lib/smbsrv/libsmbns/sparcv9/Makefile
+./src/lib/smbsrv/libsmbrdr/amd64/Makefile
+./src/lib/smbsrv/libsmbrdr/sparcv9/Makefile
 
 #
 # Ignore files only used by lint.  Eventually, linting in these areas should
--- a/usr/src/tools/ndrgen/ndrgen.sh	Mon Oct 29 15:08:19 2007 -0700
+++ b/usr/src/tools/ndrgen/ndrgen.sh	Mon Oct 29 16:16:37 2007 -0700
@@ -68,8 +68,8 @@
 		CC=$1
 		shift $(($OPTIND - 1))
 
-		# Check for cw being invoked with -_cc
-		if [[ $1 = "-_cc" ]] ; then
+		# Check for cw being invoked with -_cc or -_gcc
+		if [[ $1 = "-_cc" || $1 = "-_gcc" ]] ; then
 			CC_ARG=$1
 			shift $(($OPTIND - 1))
 		fi